@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2018 Pier Carlo Chiodi
+# Copyright (C) 2017-2020 Pier Carlo Chiodi
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -284,7 +284,7 @@ class ConfigParserProgram(object):
                         return False
 
                     if yes_no.lower() == "yes":
-                        self.cp_file(s, bak_path)
+                        self.cp_file(d, bak_path)
                         self.cp_file(s, d)
                         write_title()
                         self.v("OK (backed up and updated)")
